@@ -61,6 +61,14 @@
 
 #include "jemalloc.h"
 
+#ifndef NOJEM
+#if defined(__APPLE__) && defined(__MACH__)
+#ifndef mallctl
+#define mallctl(a, b, c, d, e) je_mallctl(a, b, c, d, e)
+#endif
+#endif // __APPLE__ and __MACH__
+#endif // NOJEM
+
 #ifdef DEBUG
 //#define VALGRIND_ENABLE_ERROR_REPORTING
 //#define VALGRIND_DISABLE_ERROR_REPORTING
@@ -79,7 +87,7 @@
 #else
 #define DEB ""
 #endif /* DEBUG */
-#define PROXYSQL_VERSION	"2.4.4-percona-1.1" DEB
+#define PROXYSQL_VERSION	"2.4.7-percona-1.1" DEB
 #define PROXYSQL_CODENAME	"Truls"
 
 #ifndef PROXYSQL_FUNC_DEFS
@@ -100,6 +108,7 @@ int pkt_end(unsigned char *, unsigned int);
 int pkt_com_query(unsigned char *, unsigned int);
 enum MySQL_response_type mysql_response(unsigned char *, unsigned int);
 
+__attribute__((__format__ (__printf__, 2, 3)))
 void proxy_error_func(int errcode, const char *, ...);
 void print_backtrace(void);
 void proxy_info_(const char* msg, ...);
@@ -107,6 +116,7 @@ void proxy_info_(const char* msg, ...);
 #ifdef DEBUG
 void init_debug_struct();
 void init_debug_struct_from_cmdline();
+__attribute__((__format__ (__printf__, 7, 8)))
 void proxy_debug_func(enum debug_module, int, int, const char *, int, const char *, const char *, ...);
 void proxy_debug_get_filters(std::set<std::string>&);
 void proxy_debug_load_filters(std::set<std::string>&);
